import logging
import os
from itertools import count
import time
import unittest
from src.DLMS_SPODES.types import cdt, cst, ut
from src.DLMS_SPODES.cosem_interface_classes import collection, overview, ln_pattern
from src.DLMS_SPODES import cosem_interface_classes
from src.DLMS_SPODES.obis import media_id
from src.DLMS_SPODES.version import AppVersion
from src.DLMS_SPODES.exceptions import NeedUpdate, NoObject


class TestType(unittest.TestCase):

    def test_dummy_class(self):
        a = collection.ProfileGenericVer0("0.0.1.0.0.255")
        print(a)

    def test_get_type_from_class(self):
        ln = cst.LogicalName("0.0.1.0.0.255")
        value = collection.get_interface_class(ut.CosemClassId(7), cdt.Unsigned(0))
        v1 = value(ln)
        print(value, v1)

    def test_add(self):
        col = collection.Collection()
        col.set_manufacturer(b"KPZ")
        col.set_server_ver(0, AppVersion(1, 4, 0))
        col.set_spec()
        ver_obj = col.add(class_id=ut.CosemClassId(1),
                          version=cdt.Unsigned(0),
                          logical_name=cst.LogicalName("0.0.96.1.6.255"))
        ver_obj.set_attr(2, "33 2e 30")

    def test_ClassMap(self):
        print(hash(collection.DataMap))

    def test_xmlCodingDecoding(self):
        col = collection.get_collection(
            manufacturer=b"KPZ",
            server_type=cdt.OctetString("4d324d5f31"),
            server_ver=AppVersion.from_str("1.5.3"))
        print(col)
        col.to_xml("test.xml")
        col.save_type("test.typ")
        ver = col.get_object("0.0.0.2.1.255")
        col.clear_server_ver()
        ver.value.set("312e312e33")
        print(ver.value)

    def test_get_object_list(self):
        col = collection.get_collection(
            manufacturer=b"KPZ",
            server_type=cdt.OctetString("4d324d5f33"),
            server_ver=AppVersion.from_str("1.4.15"))
        print(col)
        a = col.get_objects_list(collection.enums.ClientSAP(48))
        print(a)
        for i in range(10):
            col_new = collection.get_collection(
                manufacturer=b"KPZ",
                server_type=cdt.OctetString("4d324d5f33"),
                server_ver=AppVersion.from_str("1.4.16"))
            print(col_new)

    def test_to_xml3(self):
        """for template"""
        col = collection.get_collection(
            manufacturer=b"KPZ",
            server_type=cdt.OctetString("4d324d5f33"),
            server_ver=AppVersion.from_str("1.4.15"))
        clock_obj = col.get_object("0.0.1.0.0.255")
        clock_obj.set_attr(3, 120)
        act_cal = col.get_object("0.0.13.0.0.255")
        act_cal.day_profile_table_passive.append((1, [("11:00", "1.1.1.1.1.1", 1)]))
        used = {
            clock_obj.logical_name: {2, 3},
            act_cal.logical_name: {9}
        }
        col.to_xml3("test_to_xml3.xml",
                    used=used,
                    decode=True)

    def test_collection_from_xml(self):
        col, used = collection.Collection.from_xml3("test_to_xml3.xml")
        print(col, used)

    def test_get_collection(self):
        """for template"""
        for ver_txt in ("0.0.52", "1.1.9", "1.2.11", "1.3.25"):
            for manufacturer, type_ in ((b"101", "4d324d5f31"), (b"102", "4d324d5f33"), (b"103", "4d324d5f3153"), (b"104", "4d324d5f3353")):
                col = collection.get_collection(
                    manufacturer=manufacturer,
                    server_type=cdt.OctetString(type_),
                    server_ver=AppVersion.from_str(ver_txt))
                print(col)

    def test_save_type(self):
        """for template"""
        col = collection.get_collection(
            manufacturer=b"KPZ",
            server_type=cdt.OctetString("4d324d5f33"),
            server_ver=AppVersion.from_str("1.4.15"))
        col.save_type("test_save_type.typ")

    def test_to_xml4(self):
        """for template"""
        col = collection.get_collection(
            manufacturer=b"KPZ",
            server_type=cdt.OctetString("4d324d5f33"),
            server_ver=AppVersion.from_str("1.4.15"))
        col2 = collection.get_collection(
            manufacturer=b"102",
            server_type=cdt.OctetString("4d324d5f33"),
            server_ver=AppVersion.from_str("1.3.30"))
        clock_obj = col.get_object("0.0.1.0.0.255")
        clock_obj.set_attr(3, 120)
        act_cal = col.get_object("0.0.13.0.0.255")
        act_cal.day_profile_table_passive.append((1, [("11:00", "1.1.1.1.1.1", 1)]))
        used = {
            clock_obj.logical_name: {3},
            act_cal.logical_name: {9}
        }
        print(used)
        collection.to_xml4(
            collections=[col, col2],
            file_name="test_to_xml4.xml",
            used=used)
        print(used)

    def test_collection_from_xml4(self):
        cols, used, verif = collection.from_xml4("test_to_xml4.xml")
        print(cols, used, verif)

    def test_get_writable_dict(self):
        """use in template"""
        col = collection.get_collection(
            manufacturer=b"KPZ",
            server_type=cdt.OctetString("4d324d5f33"),
            server_ver=AppVersion.from_str("1.4.15"))
        ret = col.get_writable_attr()
        print(ret)

    def test_save_and_load(self):
        col = collection.get_collection(
            manufacturer=b"KPZ",
            server_type=cdt.OctetString("4d324d5f3354"),
            server_ver=AppVersion.from_str("1.4.15"))
        clock = col.get_object("0.0.1.0.0.255")
        clock.set_attr(3, 100)
        col.to_xml2("test_to_xml2.xml")
        col2 = collection.get_collection(
            manufacturer=b"KPZ",
            server_type=cdt.OctetString("4d324d5f3354"),
            server_ver=AppVersion.from_str("1.4.15"))
        col2.from_xml2("test_to_xml2.xml")

    def test_AssociationLN(self):
        col = collection.Collection()
        col.set_manufacturer(b"KPZ")
        col.set_server_ver(0, AppVersion(1, 4, 0))
        col.set_spec()
        ass_obj = col.add(class_id=overview.ClassID.ASSOCIATION_LN,
                          version=overview.Version.V1,
                          logical_name=cst.LogicalName("0.0.40.0.3.255"))
        ver_obj = col.add(class_id=overview.ClassID.DATA,
                          version=overview.Version.V0,
                          logical_name=cst.LogicalName("0.0.0.2.1.255"))
        self.assertRaises(NeedUpdate,
                          ver_obj.set_attr,
                          2,
                          bytes.fromhex("0905312e352e30"))
        ass_obj.set_attr(6, bytes.fromhex("090760857405080202"))
        print(ass_obj)

    def test_get_descriptor(self):
        col = collection.get_collection(
            manufacturer=b"KPZ",
            server_type=cdt.OctetString("4d324d5f33"),
            server_ver=AppVersion.from_str("1.4.15"))
        p = col.get_object("1.0.94.7.4.255")
        desc = p.get_attr_descriptor(2, True)
        print(col)

    def test_get_ln_contents(self):
        from src.DLMS_SPODES.types.implementations import structs
        s = structs.ValueDefinition((1, "1.2.3.4.5.6", 1))
        self.assertEqual(collection.get_ln_contents(s), b'\x01\x02\x03\x04\x05\x06')
        s = structs.ActionItem(("1.2.3.4.5.6", 1))
        self.assertEqual(collection.get_ln_contents(s), b'\x01\x02\x03\x04\x05\x06')
        s = structs.WindowElement(("01.01.200", "02.01.2000"))
        self.assertRaises(ValueError, collection.get_ln_contents, s)

    def test_path(self):
        a = collection.get_manufactures_container()
        print(a)

    def test_hash(self):
        col1 = collection.get_collection(
            manufacturer=b"KPZ",
            server_type=cdt.OctetString("4d324d5f33"),
            server_ver=AppVersion.from_str("1.4.13"))
        col2 = collection.get_collection(
            manufacturer=b"KPZ",
            server_type=cdt.OctetString("4d324d5f33"),
            server_ver=AppVersion.from_str("1.4.12"))
        c = [col1]
        print(hash(col1), hash(col2), col1 == col2, col2 in c)

    def test_get_all_collection(self):
        """try get all collection"""
        for i in collection.get_manufactures_container().values():
            for j in i.values():
                for k in j.values():
                    print(k.path)
                    col = collection.Collection.from_xml(k)
                    print(col)

    def test_copy_benchmark(self):
        """best:
        0.50.2: 0.1568sec
        0.50.3: 0.0356
        0.50.4: 0.0354
        """
        col = collection.get_collection(
            manufacturer=b"KPZ",
            server_type=cdt.OctetString("4d324d5f33"),
            server_ver=AppVersion.from_str("1.4.13"))
        n = 100
        s = time.perf_counter()
        for i in range(n):
            col.copy()
        print((time.perf_counter()-s)/n)

    def test_copy(self):
        col = collection.get_collection(
            manufacturer=b"KPZ",
            server_type=cdt.OctetString("4d324d5f33"),
            server_ver=AppVersion.from_str("1.4.13"))
        print(id(col.getAssociationBySAP(collection.enums.ClientSAP(0x30))), id(col.get_object("0.0.40.0.3.255")))
        # print(col.getAssociationBySAP.cache_info())
        # col.getAssociationBySAP.cache_clear()
        col1 = collection.get_collection(
            manufacturer=b"KPZ",
            server_type=cdt.OctetString("4d324d5f33"),
            server_ver=AppVersion.from_str("1.4.13"))
        print(id(col1.getAssociationBySAP(collection.enums.ClientSAP(0x30))), id(col1.get_object("0.0.40.0.3.255")))
        # print(col1.getAssociationBySAP.cache_info())

    def test_set_date_for_calibrator(self):
        import datetime

        col = collection.get_collection(
            manufacturer=b"KPZ",
            server_type=cdt.OctetString("4d324d5f31"),
            server_ver=AppVersion.from_str("1.5.15"))
        print(col)
        manufacture_date_obj = col.get_object('0.0.96.1.4.255')
        manufacture_date_obj.set_attr(2, datetime.date.today().strftime("%d.%m.%y"))
        print(manufacture_date_obj.value)

    def test_change_version(self):
        col = collection.get_collection(
            manufacturer=b"KPZ",
            server_type=cdt.OctetString("4d324d5f31"),
            server_ver=AppVersion.from_str("1.5.15"))
        col.change_association_version(cdt.Unsigned(2))
        print(col)

    def test_create_for_codegeneration(self):
        col = collection.get_collection(
            manufacturer=b"KPZ",
            server_type=cdt.OctetString("4d324d5f31"),
            server_ver=AppVersion.from_str("1.5.5"))
        col.to_xml("test_to_xml.xml",
                   is_decode=True)

    def test_for_change_version_in_not_valid_ass(self):
        arr: collection.ProfileGenericVer1.A_ELEMENTS[1].DATA_TYPE = cdt.Array(b"\x01\x81\x9a\x02\x04\x12\x00\x08\x11\x00\t\x06\x00\x00\x01\x00\x00\xff\x02\x02\x01\t\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x02\x03\x0f\t\x16\x03\x00\x01\x06\x02\x02\x0f\x01\x16\x01\x02\x02\x0f\x02\x16\x01\x02\x02\x0f\x03\x16\x01\x02\x02\x0f\x04\x16\x01\x02\x02\x0f\x05\x16\x01\x02\x02\x0f\x06\x16\x01\x02\x04\x12\x00\x08\x11\x00\t\x06\x00\x01\x01\x00\x00\xff\x02\x02\x01\t\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x02\x03\x0f\t\x16\x03\x00\x01\x06\x02\x02\x0f\x01\x16\x01\x02\x02\x0f\x02\x16\x01\x02\x02\x0f\x03\x16\x01\x02\x02\x0f\x04\x16\x01\x02\x02\x0f\x05\x16\x01\x02\x02\x0f\x06\x16\x01\x02\x04\x12\x00\x0f\x11\x02\t\x06\x00\x00(\x00\x00\xff\x02\x02\x01\x0b\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x02\x03\x0f\t\x16\x03\x00\x02\x03\x0f\n\x16\x03\x00\x02\x03\x0f\x0b\x16\x03\x00\x01\x06\x02\x02\x0f\x01\x16\x01\x02\x02\x0f\x02\x16\x01\x02\x02\x0f\x03\x16\x01\x02\x02\x0f\x04\x16\x01\x02\x02\x0f\x05\x16\x01\x02\x02\x0f\x06\x16\x01\x02\x04\x12\x00\x07\x11\x01\t\x06\x01\x00c\x01\x00\xff\x02\x02\x01\x08\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x01\x02\x02\x02\x0f\x01\x16\x01\x02\x02\x0f\x02\x16\x01\x02\x04\x12\x00\x07\x11\x00\t\x06\x01\x00^\x07\x04\xff\x02\x02\x01\x08\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x01\x02\x02\x02\x0f\x01\x16\x01\x02\x02\x0f\x02\x16\x01\x02\x04\x12\x00\x07\x11\x00\t\x06\x01\x00b\x02\x00\xff\x02\x02\x01\x08\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x01\x02\x02\x02\x0f\x01\x16\x01\x02\x02\x0f\x02\x16\x01\x02\x04\x12\x00\x07\x11\x00\t\x06\x01\x00^\x07\x02\xff\x02\x02\x01\x08\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x01\x02\x02\x02\x0f\x01\x16\x01\x02\x02\x0f\x02\x16\x01\x02\x04\x12\x00\x07\x11\x00\t\x06\x01\x00b\x01\x00\xff\x02\x02\x01\x08\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x01\x02\x02\x02\x0f\x01\x16\x01\x02\x02\x0f\x02\x16\x01\x02\x04\x12\x00\x07\x11\x00\t\x06\x01\x00^\x07\x01\xff\x02\x02\x01\x08\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x01\x02\x02\x02\x0f\x01\x16\x01\x02\x02\x0f\x02\x16\x01\x02\x04\x12\x00\x07\x11\x00\t\x06\x01\x00^\x07\x03\xff\x02\x02\x01\x08\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x01\x02\x02\x02\x0f\x01\x16\x01\x02\x02\x0f\x02\x16\x01\x02\x04\x12\x00\x07\x11\x00\t\x06\x01\x00^\x07\x00\xff\x02\x02\x01\x08\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x01\x02\x02\x02\x0f\x01\x16\x01\x02\x02\x0f\x02\x16\x01\x02\x04\x12\x00\x07\x11\x00\t\x06\x01\x00^\x07\x05\xff\x02\x02\x01\x08\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x01\x02\x02\x02\x0f\x01\x16\x01\x02\x02\x0f\x02\x16\x01\x02\x04\x12\x00F\x11\x00\t\x06\x00\x00`\x03\n\xff\x02\x02\x01\x04\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x01\x02\x02\x02\x0f\x01\x16\x01\x02\x02\x0f\x02\x16\x01\x02\x04\x12\x00G\x11\x00\t\x06\x00\x00\x11\x00\x00\xff\x02\x02\x01\x0b\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x02\x03\x0f\t\x16\x03\x00\x02\x03\x0f\n\x16\x03\x00\x02\x03\x0f\x0b\x16\x03\x00\x01\x00\x02\x04\x12\x00G\x11\x00\t\x06\x00\x00\x11\x00\x01\xff\x02\x02\x01\x0b\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x02\x03\x0f\t\x16\x03\x00\x02\x03\x0f\n\x16\x03\x00\x02\x03\x0f\x0b\x16\x03\x00\x01\x00\x02\x04\x12\x00G\x11\x00\t\x06\x00\x00\x11\x00\x02\xff\x02\x02\x01\x0b\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x02\x03\x0f\t\x16\x03\x00\x02\x03\x0f\n\x16\x03\x00\x02\x03\x0f\x0b\x16\x03\x00\x01\x00\x02\x04\x12\x00G\x11\x00\t\x06\x00\x00\x11\x00\x03\xff\x02\x02\x01\x0b\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x02\x03\x0f\t\x16\x03\x00\x02\x03\x0f\n\x16\x03\x00\x02\x03\x0f\x0b\x16\x03\x00\x01\x00\x02\x04\x12\x00G\x11\x00\t\x06\x00\x00\x11\x00\x04\xff\x02\x02\x01\x0b\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x02\x03\x0f\t\x16\x03\x00\x02\x03\x0f\n\x16\x03\x00\x02\x03\x0f\x0b\x16\x03\x00\x01\x00\x02\x04\x12\x00G\x11\x00\t\x06\x00\x00\x11\x00\x05\xff\x02\x02\x01\x0b\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x02\x03\x0f\t\x16\x03\x00\x02\x03\x0f\n\x16\x03\x00\x02\x03\x0f\x0b\x16\x03\x00\x01\x00\x02\x04\x12\x00\x01\x11\x00\t\x06\x00\x00\x80e\x00\xff\x02\x02\x01\x02\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x01\x00\x02\x04\x12\x00\x03\x11\x00\t\x06\x00\x00`\t\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00[\x07\x84\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\t\x11\x00\t\x06\x00\x00\n\x00j\xff\x02\x02\x01\x02\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x01\x11\x00\t\x06\x00\x00\x80\x96\x00\xff\x02\x02\x01\x02\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x01\x00\x02\x04\x12\x00\x01\x11\x00\t\x06\x00\x00`\x03\x00\xff\x02\x02\x01\x02\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x01\x00\x02\x04\x12\x00\x04\x11\x00\t\x06\x01\x00\x01\x06\x00\xff\x02\x02\x01\x05\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x07\x11\x00\t\x06\x00\x00cb\x00\xff\x02\x02\x01\x08\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x01\x02\x02\x02\x0f\x01\x16\x01\x02\x02\x0f\x02\x16\x01\x02\x04\x12\x00\x07\x11\x00\t\x06\x00\x00cb\x01\xff\x02\x02\x01\x08\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x01\x02\x02\x02\x0f\x01\x16\x01\x02\x02\x0f\x02\x16\x01\x02\x04\x12\x00\x07\x11\x00\t\x06\x00\x00cb\x02\xff\x02\x02\x01\x08\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x01\x02\x02\x02\x0f\x01\x16\x01\x02\x02\x0f\x02\x16\x01\x02\x04\x12\x00\x07\x11\x00\t\x06\x00\x00cb\x03\xff\x02\x02\x01\x08\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x01\x02\x02\x02\x0f\x01\x16\x01\x02\x02\x0f\x02\x16\x01\x02\x04\x12\x00\x07\x11\x00\t\x06\x00\x00cb\x04\xff\x02\x02\x01\x08\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x01\x02\x02\x02\x0f\x01\x16\x01\x02\x02\x0f\x02\x16\x01\x02\x04\x12\x00\x07\x11\x00\t\x06\x00\x00cb\x07\xff\x02\x02\x01\x08\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x01\x02\x02\x02\x0f\x01\x16\x01\x02\x02\x0f\x02\x16\x01\x02\x04\x12\x00\x07\x11\x00\t\x06\x00\x00cb\x1a\xff\x02\x02\x01\x08\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x01\x02\x02\x02\x0f\x01\x16\x01\x02\x02\x0f\x02\x16\x01\x02\x04\x12\x00\x07\x11\x00\t\x06\x00\x00cb\x1b\xff\x02\x02\x01\x08\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x01\x02\x02\x02\x0f\x01\x16\x01\x02\x02\x0f\x02\x16\x01\x02\x04\x12\x00\x07\x11\x00\t\x06\x00\x00cb\x05\xff\x02\x02\x01\x08\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x01\x02\x02\x02\x0f\x01\x16\x01\x02\x02\x0f\x02\x16\x01\x02\x04\x12\x00\x07\x11\x00\t\x06\x00\x00cb\x06\xff\x02\x02\x01\x08\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x01\x02\x02\x02\x0f\x01\x16\x01\x02\x02\x0f\x02\x16\x01\x02\x04\x12\x00\x07\x11\x00\t\x06\x00\x00cb\t\xff\x02\x02\x01\x08\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x01\x02\x02\x02\x0f\x01\x16\x01\x02\x02\x0f\x02\x16\x01\x02\x04\x12\x00\x07\x11\x00\t\x06\x00\x00cb\x08\xff\x02\x02\x01\x08\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x01\x02\x02\x02\x0f\x01\x16\x01\x02\x02\x0f\x02\x16\x01\x02\x04\x12\x00\x07\x11\x00\t\x06\x00\x00cb\r\xff\x02\x02\x01\x08\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x01\x02\x02\x02\x0f\x01\x16\x01\x02\x02\x0f\x02\x16\x01\x02\x04\x12\x00\x01\x11\x00\t\x06\x00\x00*\x00\x00\xff\x02\x02\x01\x02\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x01\x00\x02\x04\x12\x00\x01\x11\x00\t\x06\x00\x00`\x01\x00\xff\x02\x02\x01\x02\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x01\x00\x02\x04\x12\x00\x01\x11\x00\t\x06\x01\x01\x00\x00\x01\xff\x02\x02\x01\x02\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x01\x00\x02\x04\x12\x00\x01\x11\x00\t\x06\x00\x00^\x07\x01\xff\x02\x02\x01\x02\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x01\x00\x02\x04\x12\x00\x01\x11\x00\t\x06\x01\x00\x00\x08\x04\xff\x02\x02\x01\x02\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x01\x00\x02\x04\x12\x00\x01\x11\x00\t\x06\x00\x00`\x01\x02\xff\x02\x02\x01\x02\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x01\x00\x02\x04\x12\x00\x01\x11\x00\t\x06\x00\x00`\x01\x06\xff\x02\x02\x01\x02\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x01\x00\x02\x04\x12\x00\x01\x11\x00\t\x06\x00\x00`\x01\x03\xff\x02\x02\x01\x02\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x01\x00\x02\x04\x12\x00\x01\x11\x00\t\x06\x00\x00`\x01\n\xff\x02\x02\x01\x02\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x01\x00\x02\x04\x12\x00\x01\x11\x00\t\x06\x00\x00`\x01\x04\xff\x02\x02\x01\x02\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x01\x00\x02\x04\x12\x00\x01\x11\x00\t\x06\x01\x00\x00\x04\x02\xff\x02\x02\x01\x02\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x01\x00\x02\x04\x12\x00\x01\x11\x00\t\x06\x01\x00\x00\x04\x03\xff\x02\x02\x01\x02\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x01\x00\x02\x04\x12\x00\x01\x11\x00\t\x06\x00\x00`\x01\x01\xff\x02\x02\x01\x02\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x01\x00\x02\x04\x12\x00\x01\x11\x00\t\x06\x01\x00\x00\x03\x03\xff\x02\x02\x01\x02\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x01\x00\x02\x04\x12\x00\x01\x11\x00\t\x06\x01\x00\x00\x03\x04\xff\x02\x02\x01\x02\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x01\x00\x02\x04\x12\x00\x01\x11\x00\t\x06\x00\x00`\x01\x07\xff\x02\x02\x01\x02\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x01\x00\x02\x04\x12\x00\x01\x11\x00\t\x06\x00\x00`\x01\x08\xff\x02\x02\x01\x02\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x01\x00\x02\x04\x12\x00\x01\x11\x00\t\x06\x00\x00\x80d\x00\xff\x02\x02\x01\x02\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x01\x00\x02\x04\x12\x00\t\x11\x00\t\x06\x00\x00\n\x00d\xff\x02\x02\x01\x02\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x16\x11\x00\t\x06\x00\x00\x0f\x00\x00\xff\x02\x02\x01\x04\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x01\x00\x02\x04\x12\x00\x14\x11\x00\t\x06\x00\x00\r\x00\x00\xff\x02\x02\x01\n\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x02\x03\x0f\t\x16\x03\x00\x02\x03\x0f\n\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x0b\x11\x00\t\x06\x00\x00\x0b\x00\x00\xff\x02\x02\x01\x02\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x01\x02\x02\x02\x0f\x01\x16\x01\x02\x02\x0f\x02\x16\x01\x02\x04\x12\x00\x12\x11\x00\t\x06\x00\x00,\x00\x00\xff\x02\x02\x01\x07\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x01\x04\x02\x02\x0f\x01\x16\x01\x02\x02\x0f\x02\x16\x01\x02\x02\x0f\x03\x16\x01\x02\x02\x0f\x04\x16\x01\x02\x04\x12\x00\x12\x11\x00\t\x06\x00\x00,\x00\x80\xff\x02\x02\x01\x07\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x01\x04\x02\x02\x0f\x01\x16\x01\x02\x02\x0f\x02\x16\x01\x02\x02\x0f\x03\x16\x01\x02\x02\x0f\x04\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x1f\x07\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x003\x07\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00G\x07\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00[\x07\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x0b\x07\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00 \x07\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x004\x07\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00H\x07\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x0e\x07\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x0c\x07\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x0c\x1b\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x0c\x07\x01\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x0c\x07\x02\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x0c\x07\x03\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00Q\x07\x02\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00Q\x07\n\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00Q\x07\x15\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00Q\x07\x04\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00Q\x07\x0f\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00Q\x07\x1a\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x0f\x10\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x0f\x10\x01\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x0f\x06\x80\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x89\x06\x80\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x0f\x06\x81\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x0f\x06\x82\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\t\x06\x80\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x01\x08\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x01\x08\x01\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x01\x08\x02\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x01\x08\x03\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x01\x08\x04\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x02\x08\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x02\x08\x01\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x02\x08\x02\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x02\x08\x03\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x02\x08\x04\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x03\x08\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x03\x08\x01\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x03\x08\x02\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x03\x08\x03\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x03\x08\x04\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x04\x08\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x04\x08\x01\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x04\x08\x02\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x04\x08\x03\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x04\x08\x04\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00!\x07\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00I\x07\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x005\x07\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\t\x07\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x1d\x07\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x001\x07\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00E\x07\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x01\x07\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x15\x07\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00)\x07\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00=\x07\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x03\x07\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x17\x07\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00+\x07\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00?\x07\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\r\x07\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x0c'\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x80\x00\x00\x00\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x80\x00\x01\x00\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x80\x00\x02\x00\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x80\x00\x03\x00\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x80\x00\x04\x00\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x80\x00\x05\x00\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x80\x00\x06\x00\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x80\x00\x07\x00\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x80\x00\x08\x00\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x80\x00\t\x00\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x80\x00\n\x00\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x80\x00\x0b\x00\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x80\x00\x0c\x00\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x80\x00\r\x00\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x80\x00\x0e\x00\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x80\x00\x0f\x00\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x80\x00\x10\x00\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x80\x00\x11\x00\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x80\x00\x12\x00\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x80\x00\x13\x00\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x00\x06\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x00\x06\x01\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x00\x06\x02\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x00\x06\x03\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x01\x02\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x00\x06\x04\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x0f\x10\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01")
        arr = cdt.Array(b"\x01\x81\x9a\x02\x04\x12\x00\x08\x11\x00\t\x06\x00\x00\x01\x00\x00\xff\x02\x02\x01\t\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x02\x03\x0f\t\x16\x03\x00\x01\x06\x02\x02\x0f\x01\x16\x01\x02\x02\x0f\x02\x16\x01\x02\x02\x0f\x03\x16\x01\x02\x02\x0f\x04\x16\x01\x02\x02\x0f\x05\x16\x01\x02\x02\x0f\x06\x16\x01\x02\x04\x12\x00\x08\x11\x00\t\x06\x00\x01\x01\x00\x00\xff\x02\x02\x01\t\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x02\x03\x0f\t\x16\x03\x00\x01\x06\x02\x02\x0f\x01\x16\x01\x02\x02\x0f\x02\x16\x01\x02\x02\x0f\x03\x16\x01\x02\x02\x0f\x04\x16\x01\x02\x02\x0f\x05\x16\x01\x02\x02\x0f\x06\x16\x01\x02\x04\x12\x00\x0f\x11\x02\t\x06\x00\x00(\x00\x00\xff\x02\x02\x01\x0b\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x02\x03\x0f\t\x16\x03\x00\x02\x03\x0f\n\x16\x03\x00\x02\x03\x0f\x0b\x16\x03\x00\x01\x06\x02\x02\x0f\x01\x16\x01\x02\x02\x0f\x02\x16\x01\x02\x02\x0f\x03\x16\x01\x02\x02\x0f\x04\x16\x01\x02\x02\x0f\x05\x16\x01\x02\x02\x0f\x06\x16\x01\x02\x04\x12\x00\x07\x11\x01\t\x06\x01\x00c\x01\x00\xff\x02\x02\x01\x08\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x01\x02\x02\x02\x0f\x01\x16\x01\x02\x02\x0f\x02\x16\x01\x02\x04\x12\x00\x07\x11\x01\t\x06\x01\x00^\x07\x04\xff\x02\x02\x01\x08\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x01\x02\x02\x02\x0f\x01\x16\x01\x02\x02\x0f\x02\x16\x01\x02\x04\x12\x00\x07\x11\x01\t\x06\x01\x00b\x02\x00\xff\x02\x02\x01\x08\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x01\x02\x02\x02\x0f\x01\x16\x01\x02\x02\x0f\x02\x16\x01\x02\x04\x12\x00\x07\x11\x01\t\x06\x01\x00^\x07\x02\xff\x02\x02\x01\x08\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x01\x02\x02\x02\x0f\x01\x16\x01\x02\x02\x0f\x02\x16\x01\x02\x04\x12\x00\x07\x11\x01\t\x06\x01\x00b\x01\x00\xff\x02\x02\x01\x08\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x01\x02\x02\x02\x0f\x01\x16\x01\x02\x02\x0f\x02\x16\x01\x02\x04\x12\x00\x07\x11\x01\t\x06\x01\x00^\x07\x01\xff\x02\x02\x01\x08\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x01\x02\x02\x02\x0f\x01\x16\x01\x02\x02\x0f\x02\x16\x01\x02\x04\x12\x00\x07\x11\x01\t\x06\x01\x00^\x07\x03\xff\x02\x02\x01\x08\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x01\x02\x02\x02\x0f\x01\x16\x01\x02\x02\x0f\x02\x16\x01\x02\x04\x12\x00\x07\x11\x01\t\x06\x01\x00^\x07\x00\xff\x02\x02\x01\x08\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x01\x02\x02\x02\x0f\x01\x16\x01\x02\x02\x0f\x02\x16\x01\x02\x04\x12\x00\x07\x11\x01\t\x06\x01\x00^\x07\x05\xff\x02\x02\x01\x08\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x01\x02\x02\x02\x0f\x01\x16\x01\x02\x02\x0f\x02\x16\x01\x02\x04\x12\x00F\x11\x00\t\x06\x00\x00`\x03\n\xff\x02\x02\x01\x04\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x01\x02\x02\x02\x0f\x01\x16\x01\x02\x02\x0f\x02\x16\x01\x02\x04\x12\x00G\x11\x00\t\x06\x00\x00\x11\x00\x00\xff\x02\x02\x01\x0b\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x02\x03\x0f\t\x16\x03\x00\x02\x03\x0f\n\x16\x03\x00\x02\x03\x0f\x0b\x16\x03\x00\x01\x00\x02\x04\x12\x00G\x11\x00\t\x06\x00\x00\x11\x00\x01\xff\x02\x02\x01\x0b\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x02\x03\x0f\t\x16\x03\x00\x02\x03\x0f\n\x16\x03\x00\x02\x03\x0f\x0b\x16\x03\x00\x01\x00\x02\x04\x12\x00G\x11\x00\t\x06\x00\x00\x11\x00\x02\xff\x02\x02\x01\x0b\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x02\x03\x0f\t\x16\x03\x00\x02\x03\x0f\n\x16\x03\x00\x02\x03\x0f\x0b\x16\x03\x00\x01\x00\x02\x04\x12\x00G\x11\x00\t\x06\x00\x00\x11\x00\x03\xff\x02\x02\x01\x0b\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x02\x03\x0f\t\x16\x03\x00\x02\x03\x0f\n\x16\x03\x00\x02\x03\x0f\x0b\x16\x03\x00\x01\x00\x02\x04\x12\x00G\x11\x00\t\x06\x00\x00\x11\x00\x04\xff\x02\x02\x01\x0b\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x02\x03\x0f\t\x16\x03\x00\x02\x03\x0f\n\x16\x03\x00\x02\x03\x0f\x0b\x16\x03\x00\x01\x00\x02\x04\x12\x00G\x11\x00\t\x06\x00\x00\x11\x00\x05\xff\x02\x02\x01\x0b\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x02\x03\x0f\t\x16\x03\x00\x02\x03\x0f\n\x16\x03\x00\x02\x03\x0f\x0b\x16\x03\x00\x01\x00\x02\x04\x12\x00\x01\x11\x00\t\x06\x00\x00\x80e\x00\xff\x02\x02\x01\x02\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x01\x00\x02\x04\x12\x00\x03\x11\x00\t\x06\x00\x00`\t\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00[\x07\x84\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\t\x11\x00\t\x06\x00\x00\n\x00j\xff\x02\x02\x01\x02\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x01\x11\x00\t\x06\x00\x00\x80\x96\x00\xff\x02\x02\x01\x02\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x01\x00\x02\x04\x12\x00\x01\x11\x00\t\x06\x00\x00`\x03\x00\xff\x02\x02\x01\x02\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x01\x00\x02\x04\x12\x00\x04\x11\x00\t\x06\x01\x00\x01\x06\x00\xff\x02\x02\x01\x05\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x07\x11\x01\t\x06\x00\x00cb\x00\xff\x02\x02\x01\x08\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x01\x02\x02\x02\x0f\x01\x16\x01\x02\x02\x0f\x02\x16\x01\x02\x04\x12\x00\x07\x11\x01\t\x06\x00\x00cb\x01\xff\x02\x02\x01\x08\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x01\x02\x02\x02\x0f\x01\x16\x01\x02\x02\x0f\x02\x16\x01\x02\x04\x12\x00\x07\x11\x01\t\x06\x00\x00cb\x02\xff\x02\x02\x01\x08\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x01\x02\x02\x02\x0f\x01\x16\x01\x02\x02\x0f\x02\x16\x01\x02\x04\x12\x00\x07\x11\x01\t\x06\x00\x00cb\x03\xff\x02\x02\x01\x08\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x01\x02\x02\x02\x0f\x01\x16\x01\x02\x02\x0f\x02\x16\x01\x02\x04\x12\x00\x07\x11\x01\t\x06\x00\x00cb\x04\xff\x02\x02\x01\x08\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x01\x02\x02\x02\x0f\x01\x16\x01\x02\x02\x0f\x02\x16\x01\x02\x04\x12\x00\x07\x11\x01\t\x06\x00\x00cb\x07\xff\x02\x02\x01\x08\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x01\x02\x02\x02\x0f\x01\x16\x01\x02\x02\x0f\x02\x16\x01\x02\x04\x12\x00\x07\x11\x01\t\x06\x00\x00cb\x1a\xff\x02\x02\x01\x08\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x01\x02\x02\x02\x0f\x01\x16\x01\x02\x02\x0f\x02\x16\x01\x02\x04\x12\x00\x07\x11\x01\t\x06\x00\x00cb\x1b\xff\x02\x02\x01\x08\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x01\x02\x02\x02\x0f\x01\x16\x01\x02\x02\x0f\x02\x16\x01\x02\x04\x12\x00\x07\x11\x01\t\x06\x00\x00cb\x05\xff\x02\x02\x01\x08\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x01\x02\x02\x02\x0f\x01\x16\x01\x02\x02\x0f\x02\x16\x01\x02\x04\x12\x00\x07\x11\x01\t\x06\x00\x00cb\x06\xff\x02\x02\x01\x08\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x01\x02\x02\x02\x0f\x01\x16\x01\x02\x02\x0f\x02\x16\x01\x02\x04\x12\x00\x07\x11\x01\t\x06\x00\x00cb\t\xff\x02\x02\x01\x08\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x01\x02\x02\x02\x0f\x01\x16\x01\x02\x02\x0f\x02\x16\x01\x02\x04\x12\x00\x07\x11\x01\t\x06\x00\x00cb\x08\xff\x02\x02\x01\x08\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x01\x02\x02\x02\x0f\x01\x16\x01\x02\x02\x0f\x02\x16\x01\x02\x04\x12\x00\x07\x11\x01\t\x06\x00\x00cb\r\xff\x02\x02\x01\x08\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x01\x02\x02\x02\x0f\x01\x16\x01\x02\x02\x0f\x02\x16\x01\x02\x04\x12\x00\x01\x11\x00\t\x06\x00\x00*\x00\x00\xff\x02\x02\x01\x02\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x01\x00\x02\x04\x12\x00\x01\x11\x00\t\x06\x00\x00`\x01\x00\xff\x02\x02\x01\x02\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x01\x00\x02\x04\x12\x00\x01\x11\x00\t\x06\x01\x01\x00\x00\x01\xff\x02\x02\x01\x02\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x01\x00\x02\x04\x12\x00\x01\x11\x00\t\x06\x00\x00^\x07\x01\xff\x02\x02\x01\x02\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x01\x00\x02\x04\x12\x00\x01\x11\x00\t\x06\x01\x00\x00\x08\x04\xff\x02\x02\x01\x02\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x01\x00\x02\x04\x12\x00\x01\x11\x00\t\x06\x00\x00`\x01\x02\xff\x02\x02\x01\x02\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x01\x00\x02\x04\x12\x00\x01\x11\x00\t\x06\x00\x00`\x01\x06\xff\x02\x02\x01\x02\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x01\x00\x02\x04\x12\x00\x01\x11\x00\t\x06\x00\x00`\x01\x03\xff\x02\x02\x01\x02\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x01\x00\x02\x04\x12\x00\x01\x11\x00\t\x06\x00\x00`\x01\n\xff\x02\x02\x01\x02\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x01\x00\x02\x04\x12\x00\x01\x11\x00\t\x06\x00\x00`\x01\x04\xff\x02\x02\x01\x02\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x01\x00\x02\x04\x12\x00\x01\x11\x00\t\x06\x01\x00\x00\x04\x02\xff\x02\x02\x01\x02\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x01\x00\x02\x04\x12\x00\x01\x11\x00\t\x06\x01\x00\x00\x04\x03\xff\x02\x02\x01\x02\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x01\x00\x02\x04\x12\x00\x01\x11\x00\t\x06\x00\x00`\x01\x01\xff\x02\x02\x01\x02\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x01\x00\x02\x04\x12\x00\x01\x11\x00\t\x06\x01\x00\x00\x03\x03\xff\x02\x02\x01\x02\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x01\x00\x02\x04\x12\x00\x01\x11\x00\t\x06\x01\x00\x00\x03\x04\xff\x02\x02\x01\x02\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x01\x00\x02\x04\x12\x00\x01\x11\x00\t\x06\x00\x00`\x01\x07\xff\x02\x02\x01\x02\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x01\x00\x02\x04\x12\x00\x01\x11\x00\t\x06\x00\x00`\x01\x08\xff\x02\x02\x01\x02\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x01\x00\x02\x04\x12\x00\x01\x11\x00\t\x06\x00\x00\x80d\x00\xff\x02\x02\x01\x02\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x01\x00\x02\x04\x12\x00\t\x11\x00\t\x06\x00\x00\n\x00d\xff\x02\x02\x01\x02\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x16\x11\x00\t\x06\x00\x00\x0f\x00\x00\xff\x02\x02\x01\x04\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x01\x00\x02\x04\x12\x00\x14\x11\x00\t\x06\x00\x00\r\x00\x00\xff\x02\x02\x01\n\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x03\x00\x02\x03\x0f\t\x16\x03\x00\x02\x03\x0f\n\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x0b\x11\x00\t\x06\x00\x00\x0b\x00\x00\xff\x02\x02\x01\x02\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x01\x02\x02\x02\x0f\x01\x16\x01\x02\x02\x0f\x02\x16\x01\x02\x04\x12\x00\x12\x11\x00\t\x06\x00\x00,\x00\x00\xff\x02\x02\x01\x07\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x01\x04\x02\x02\x0f\x01\x16\x01\x02\x02\x0f\x02\x16\x01\x02\x02\x0f\x03\x16\x01\x02\x02\x0f\x04\x16\x01\x02\x04\x12\x00\x12\x11\x00\t\x06\x00\x00,\x00\x80\xff\x02\x02\x01\x07\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x02\x03\x0f\x04\x16\x03\x00\x02\x03\x0f\x05\x16\x03\x00\x02\x03\x0f\x06\x16\x03\x00\x02\x03\x0f\x07\x16\x03\x00\x01\x04\x02\x02\x0f\x01\x16\x01\x02\x02\x0f\x02\x16\x01\x02\x02\x0f\x03\x16\x01\x02\x02\x0f\x04\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x1f\x07\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x003\x07\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00G\x07\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00[\x07\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x0b\x07\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00 \x07\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x004\x07\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00H\x07\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x0e\x07\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x0c\x07\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x0c\x1b\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x0c\x07\x01\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x0c\x07\x02\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x0c\x07\x03\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00Q\x07\x02\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00Q\x07\n\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00Q\x07\x15\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00Q\x07\x04\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00Q\x07\x0f\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00Q\x07\x1a\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x0f\x10\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x0f\x10\x01\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x0f\x06\x80\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x89\x06\x80\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x0f\x06\x81\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x0f\x06\x82\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\t\x06\x80\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x01\x08\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x01\x08\x01\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x01\x08\x02\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x01\x08\x03\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x01\x08\x04\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x02\x08\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x02\x08\x01\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x02\x08\x02\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x02\x08\x03\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x02\x08\x04\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x03\x08\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x03\x08\x01\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x03\x08\x02\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x03\x08\x03\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x03\x08\x04\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x04\x08\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x04\x08\x01\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x04\x08\x02\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x04\x08\x03\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x04\x08\x04\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00!\x07\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00I\x07\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x005\x07\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\t\x07\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x1d\x07\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x001\x07\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00E\x07\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x01\x07\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x15\x07\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00)\x07\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00=\x07\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x03\x07\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x17\x07\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00+\x07\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00?\x07\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\r\x07\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x0c'\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x80\x00\x00\x00\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x80\x00\x01\x00\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x80\x00\x02\x00\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x80\x00\x03\x00\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x80\x00\x04\x00\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x80\x00\x05\x00\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x80\x00\x06\x00\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x80\x00\x07\x00\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x80\x00\x08\x00\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x80\x00\t\x00\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x80\x00\n\x00\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x80\x00\x0b\x00\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x80\x00\x0c\x00\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x80\x00\r\x00\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x80\x00\x0e\x00\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x80\x00\x0f\x00\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x80\x00\x10\x00\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x80\x00\x11\x00\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x80\x00\x12\x00\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x80\x00\x13\x00\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x00\x06\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x00\x06\x01\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x00\x06\x02\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x00\x06\x03\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x01\x02\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x00\x06\x04\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01\x02\x04\x12\x00\x03\x11\x00\t\x06\x01\x00\x0f\x10\x00\xff\x02\x02\x01\x03\x02\x03\x0f\x01\x16\x03\x00\x02\x03\x0f\x02\x16\x03\x00\x02\x03\x0f\x03\x16\x03\x00\x01\x01\x02\x02\x0f\x01\x16\x01")
        for i in arr:
            print(i)
            if int(i[0]) == 7 and int(ver := i[1]) == 0:
                ver.set(1)
                print(ver)
            if int(i[0]) == 15:
                for j in i[3][0]:
                    if int(j[0]) in (3, 4, 5, 6, 8):
                        j[1].set(1)
        print(arr.encoding.hex())

        struct = cdt.Structure(b'\x02\x04\x12\x00\x0f\x11\x02\t\x06\x00\x00(\x00\x01\xff\x02\x02\x01\x0b\x02\x03\x0f\x01\x16\x01\x00\x02\x03\x0f\x02\x16\x01\x00\x02\x03\x0f\x03\x16\x01\x00\x02\x03\x0f\x04\x16\x01\x00\x02\x03\x0f\x05\x16\x01\x00\x02\x03\x0f\x06\x16\x01\x00\x02\x03\x0f\x07\x16\x03\x00\x02\x03\x0f\x08\x16\x01\x00\x02\x03\x0f\t\x16\x01\x00\x02\x03\x0f\n\x16\x01\x00\x02\x03\x0f\x0b\x16\x01\x00\x01\x06\x02\x02\x0f\x01\x16\x01\x02\x02\x0f\x02\x16\x01\x02\x02\x0f\x03\x16\x01\x02\x02\x0f\x04\x16\x01\x02\x02\x0f\x05\x16\x01\x02\x02\x0f\x06\x16\x01')
        for i in struct[3]:
            for j in i:
                print(j)

    def test_one_Type(self):
        col = collection.get_collection(
            manufacturer=b"101",
            server_type=cdt.OctetString("4d324d5f31"),
            server_ver=AppVersion.from_str("0.0.49"))
        print(col)

    def test_one_Type2(self):
        col = collection.get_collection(
            manufacturer=b"KPZ",
            server_type=cdt.OctetString("4d324d5f31"),
            server_ver=AppVersion.from_str("1.5.1"))
        print(col)

    def test_transpose_objects(self):
        type_ = "4d324d5f31"
        ver = "0.0.49"
        man = b"101"
        col = collection.get(
            m=man,
            t=cdt.OctetString(type_),
            ver=AppVersion.from_str(ver))
        for obj in col:
            match obj.CLASS_ID:
                case collection.ClassID.PROFILE_GENERIC:
                    obj: collection.ProfileGeneric
                    if not obj.sort_object:
                        obj.set_attr(6, (8, "0.0.1.0.0.255", 2, 0))
                        print(F"set {obj.sort_object=}")
                    elif int(obj.sort_object.attribute_index) != 2:
                        obj.sort_object.attribute_index.set(2)
                        print(F"set {obj.sort_object.attribute_index=}")
                case collection.ClassID.ASSOCIATION_LN:
                    obj.set_attr(6, bytes.fromhex("09 07 60 85 74 05 08 02 01"))
        col.set_server_ver(0, col.collection_ver)  # server as well as collection
        col.save_type(F"{man}_{type_}_{ver}.typ")

    def test_transpose_fix(self):
        type_ = "4d324d5f3354"
        ver = "1.5.7"
        man = b"KPZ"
        col = collection.get(
            m=man,
            t=cdt.OctetString(type_),
            ver=AppVersion.from_str(ver))
        col.set_server_ver(0, col.collection_ver)  # server as well as collection
        col.save_type(F"{man}_{type_}_{ver}.typ")

    def test_get_class_names(self):
        type_ = "4d324d5f3354"
        ver = "1.5.7"
        man = b"KPZ"
        col = collection.get(
            m=man,
            t=cdt.OctetString(type_),
            ver=AppVersion.from_str(ver))
        for obj in col:
            print(str(obj.CLASS_ID))

    def test_create_manufacture_obj(self):
        col = collection.Collection()
        obj = col.add(
            class_id=overview.ClassID.DATA,
            version=overview.Version.V0,
            logical_name=cst.LogicalName("0.128.25.6.0.255")
        )
        print(obj)

    def test_get_phases_amount(self):
        type_ = "4d324d5f31"
        ver = "1.5.7"
        man = b"KPZ"
        col = collection.get(
            m=man,
            t=cdt.OctetString(type_),
            ver=AppVersion.from_str(ver))
        self.assertEqual(col.get_n_phases(), 1, "check amount")
        type_ = "4d324d5f33"
        ver = "1.5.7"
        man = b"KPZ"
        col = collection.get(
            m=man,
            t=cdt.OctetString(type_),
            ver=AppVersion.from_str(ver))
        col.get_class_version()
        self.assertEqual(col.get_n_phases(), 3, "check amount 3")
        kpz_ip = col.get_object("0.128.154.0.0.255")
        kpz_ip.set_attr(2, (1, ["0.0.0.0", "0.0.0.1"]))
        print(kpz_ip)
        print(overview.ClassID.get_all_id())

    def test_get_object_list_desc(self):
        self.assertEqual(collection.AttrDesc.OBJECT_LIST.contents, b'\x00\x0f\x00\x00(\x00\x00\xff\x02\x00', "check cached object_list")

    def test_get_relation_group(self):
        ln = cst.LogicalName("0.0.1.0.0.255")
        self.assertEqual(collection.get_relation_group(ln), collection.media_id.CLOCK_OBJECTS, "check_group")
        b1 = collection.get_media_id(ln)
        ln = cst.LogicalName("0.0.94.1.1.255")
        a = collection.get_relation_group(ln)
        b2 = collection.get_media_id(ln)
        print(a)

    def test_group_objects(self):
        type_ = "4d324d5f31"
        ver = "1.5.7"
        man = b"KPZ"
        col = collection.get(
            m=man,
            t=cdt.OctetString(type_),
            ver=AppVersion.from_str(ver))
        c = col.filter_by_ass(1)
        print(c)
        d = list(collection.group_filter(c, collection.RelationGroup.DEVICE_ID_OBJECTS))
        print(d)
        e = list(collection.class_id_filter(d, collection.ClassID.DATA))
        print(e)
        f = list(collection.group_filter(c, (collection.RelationGroup.DEVICE_ID_OBJECTS, collection.RelationGroup.CLOCK_OBJECTS)))
        print(f)
        g = list(collection.params_filter(col, (collection.RelationGroup.CLOCK_OBJECTS, collection.media_id.ELECTRICITY)))
        print(g)

    def test_media_id(self):
        a = collection.media_id.MediaId.from_int(1)
        b = collection.media_id.ELECTRICITY
        print(a is b)
        print(b)
        c = media_id.THRESHOLD_VALUES
        print(c)

        import inspect
        import sys

        clsmembers = inspect.getmembers(media_id, inspect.isclass)
        for it in clsmembers:
            print(F'{it[0]} = ""')

    def test_get_tree(self):
        from src.DLMS_SPODES.obis.media_id import MediaId
        type_ = "4d324d5f31"
        ver = "1.5.7"
        man = b"KPZ"
        col = collection.get(
            m=man,
            t=cdt.OctetString(type_),
            ver=AppVersion.from_str(ver))
        res = collection.get_object_tree(
            objects=col.filter_by_ass(3),
            # mode="gmc"
            mode="c"
        )
        print(res)

    def test_sort_objects(self):
        type_ = "4d324d5f31"
        ver = "1.5.7"
        man = b"KPZ"
        col = collection.get(
            m=man,
            t=cdt.OctetString(type_),
            ver=AppVersion.from_str(ver))
        res = collection.get_sorted(col.filter_by_ass(3), mode="l")
        res = collection.get_sorted(col.filter_by_ass(3), mode="n")
        res = collection.get_sorted(col.filter_by_ass(3), mode="c")
        print(res)

    def test_get_filtered(self):
        type_ = "4d324d5f31"
        ver = "1.6.2"
        man = b"KPZ"
        col = collection.get(
            m=man,
            t=cdt.OctetString(type_),
            ver=AppVersion.from_str(ver))
        res = collection.get_filtered(
            objects=col.filter_by_ass(3),
            keys=(collection.ClassID.DATA, collection.ClassID.REGISTER, collection.media_id.ELECTRICITY))
        print(res)
        res2 = collection.get_filtered(
                objects=col,
                keys=(ln_pattern.DEVICE_ID,
                      ln_pattern.PROGRAM_ENTRIES))
        print(res2)
        res3 = collection.get_filtered(
            objects=col,
            keys=(
                ln_pattern.TARIFFICATION_SCRIPT_TABLE,
                overview.ClassID.SCHEDULE,
                overview.ClassID.ACTIVITY_CALENDAR,
                overview.ClassID.SPECIAL_DAYS_TABLE,
            )
        )
        print(res3)

    def test_get_attr_tree(self):
        type_ = "4d324d5f31"
        ver = "1.5.7"
        man = b"KPZ"
        col = collection.get(
            m=man,
            t=cdt.OctetString(type_),
            ver=AppVersion.from_str(ver))
        res = col.get_attr_tree(
            ass_id=3,
            obj_mode="",
            # obj_filter=(collection.ClassID.REGISTER, collection.media_id.ABSTRACT),
            # obj_filter=(collection.ClassID.REGISTER,),
            sort_mode="l",
            af_mode="lrw",
            ai_filter=((overview.ClassID.REGISTER, (2,)),)
        )
        print(res)

    def test_LNPattern(self):
        pattern = collection.LNPattern("a.2.(1, 200, 43, 51, 3-8).4.5.9")
        pat3 = ln_pattern.GENERAL_AND_SERVICE_ENTRY_OBJECTS
        pattern2 = collection.LNPattern("a.2.31.4.5.9")
        print(pattern)
        print(cst.LogicalName("1.2.31.4.5.9") in (pattern, pattern2))
        type_ = "4d324d5f31"
        ver = "1.5.7"
        man = b"KPZ"
        col = collection.get(
            m=man,
            t=cdt.OctetString(type_),
            ver=AppVersion.from_str(ver))
        res = collection.get_filtered(
            objects=col.filter_by_ass(3),
            # keys=(collection.LNPattern("a.b.(14-20).d.e.f"),)
            keys=(pat3,)
        )
        print(res)

    def test_get_scaler_unit(self):
        type_ = "4d324d5f31"
        ver = "1.5.7"
        man = b"KPZ"
        col = collection.get(
            m=man,
            t=cdt.OctetString(type_),
            ver=AppVersion.from_str(ver))

        for obj in col:
            for i, a_val in obj.get_index_with_attributes():
                if i == 1:
                    continue
                res = col.get_scaler_unit(
                    ln=obj.logical_name,
                    par=[i])
                print(F"{obj.CLASS_ID} {obj.logical_name.get_report()}:{i} {res}")

    def test_get_report(self):
        type_ = "4d324d5f31"
        ver = "1.5.7"
        man = b"KPZ"
        col = collection.get(
            m=man,
            t=cdt.OctetString(type_),
            ver=AppVersion.from_str(ver))
        rep_count = count()
        # for obj in collection.get_filtered(col, (collection.ClassID.LIMITER,)):
        for obj in col:
            for i, _ in obj.get_index_with_attributes():
                if i == 1:
                    continue
                par = bytearray([i])
                value = obj.get_attr(i)
                stack = [(value, par)]
                while stack:
                    value, par = stack.pop()
                    rep = col.get_report(obj, bytes(par), value)
                    print(F"{obj.logical_name.get_report()} {i}: {rep=}")
                    next(rep_count)
                    match value:
                        case cdt.Structure():
                            for j, el in enumerate(value):
                                new_par = par.copy()
                                new_par.append(j)
                                stack.append((el, new_par))
                        case cdt.Array():
                            new_par = par.copy()
                            new_par.append(0)
                            for j, el in enumerate(value):
                                stack.append((el, new_par))
        print(F"{col.get_scaler_unit.cache_info()=}")
        print(F"{collection.get_unit.cache_info()=}")
        print(F"{rep_count=}")

    def test_get_profile_s_u(self):
        type_ = "4d324d5f31"
        ver = "1.5.7"
        man = b"KPZ"
        col = collection.get(
            m=man,
            t=cdt.OctetString(type_),
            ver=AppVersion.from_str(ver))
        res = col.get_profile_s_u(
            obj=col.get_object("1.0.99.2.0.255"),
            mask=None
        )
        print(res)

    def test_Spodes_locker_obj(self):
        type_ = "4d324d5f31"
        ver = "1.6.2"
        man = b"KPZ"
        col = collection.get(
            m=man,
            t=cdt.OctetString(type_),
            ver=AppVersion.from_str(ver))
        locker = col.get_object("0.0.96.4.3.255")
        locker.set_attr(2, 0)
        rep = col.get_report(locker, b'\x02', locker.value)
        print(locker, rep)

    def test_report_enums(self):
        from src.DLMS_SPODES.cosem_interface_classes.association_ln.mechanism_id import MechanismIdElement
        type_ = "4d324d5f31"
        ver = "1.6.2"
        man = b"KPZ"
        col = collection.get(
            m=man,
            t=cdt.OctetString(type_),
            ver=AppVersion.from_str(ver))
        clock_obj = col.get_object('0.0.1.0.0.255')
        clock_obj.set_attr(9, 3)
        print(clock_obj.clock_base)
        print(col.get_report(clock_obj, b'\x09', clock_obj.clock_base))
        ass_obj = col.get_object("0.0.40.0.1.255")
        print(ass_obj.authentication_mechanism_name.authentication_mechanism_name_element)
        m_id = MechanismIdElement(0)
        m_id.set('2')
        print(F"{m_id=}")
        vol_ev_obj = col.get_object("0.0.96.11.0.255")
        vol_ev_obj.set_attr(2, 33)
        print(col.get_report(vol_ev_obj, b'\x02', vol_ev_obj.value))
        col.add(collection.ClassID.DATA, overview.Version.V0, cst.LogicalName("0.0.96.5.1.255"))
        vol_ev_obj = col.get_object("0.0.96.5.1.255")
        vol_ev_obj.set_attr(2, 5)
        print(col.get_report(vol_ev_obj, b'\x02', vol_ev_obj.value))
        vol_ev_obj = col.get_object("0.0.96.5.4.255")
        vol_ev_obj.set_attr(2, 1)
        print(col.get_report(vol_ev_obj, b'\x02', vol_ev_obj.value))
